@@ -120,7 +120,7 @@ class WheelRepair:
         with open(init_path) as file:
             init_contents = file.read()
         node = ast.parse(init_contents)
-        docstring = ast.get_docstring(node)
+        docstring = ast.get_docstring(node, False)
 
         rand_num = random.randint(10 ** 10, 10 ** 11 - 1)
         patch_init_contents = _patch_init_template.format(rand_num, libs_dir)
@@ -339,6 +339,11 @@ class WheelRepair:
                     item != f'{distribution_name}-{version}.data' and \
                     item != libs_dir_name:
                 self._patch_init(os.path.join(self._extract_dir, item, '__init__.py'), libs_dir_name)
+        purelib_dir = os.path.join(self._extract_dir, f'{distribution_name}-{version}.data', 'purelib')
+        if os.path.isdir(purelib_dir):
+            for item in os.listdir(purelib_dir):
+                if os.path.isdir(os.path.join(purelib_dir, item)):
+                    self._patch_init(os.path.join(purelib_dir, item, '__init__.py'), libs_dir_name)
 
         # update record file, which tracks wheel contents and their checksums
         dist_info_foldername = '-'.join(self._whl_name.split('-')[:2]) + '.dist-info'
